sqlobject.tests.test_empty module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_empty module

class `sqlobject.tests.test_empty.` `EmptyClass`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = empty_class
  `q` = empty_class
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_empty.EmptyClass`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'empty_class'

`sqlobject.tests.test_empty.` `test_empty`()